"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEffectiveLogLevels = void 0;
const invalidArgument_exception_1 = require("../exceptions/invalidArgument.exception");
const getEffectiveLogLevels = (minLogLevel, defaultLogLevel = 'debug', allowedLogLevels = ['warn', 'debug', 'verbose']) => {
    const allLogLevelsSorted = ['log', 'error', 'warn', 'debug', 'verbose'];
    const requiredLogLevel = (minLogLevel || defaultLogLevel);
    if (!allowedLogLevels.includes(requiredLogLevel))
        throw new invalidArgument_exception_1.InvalidArgumentException('minLogLevel', `Invalid minLogLevel: ${requiredLogLevel}. Allowed log levels: ${allowedLogLevels.join(', ')}`);
    const effectiveLogLevels = allLogLevelsSorted.slice(0, allLogLevelsSorted.indexOf(requiredLogLevel) + 1);
    return effectiveLogLevels;
};
exports.getEffectiveLogLevels = getEffectiveLogLevels;
//# sourceMappingURL=logger.utils.js.map